
class Singleton( type ):
    """
    A textbook singleton implementation as a metaclass.
    """

    _instances = {}

    def __call__( cls, *args, **kwargs ):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__( *args, **kwargs )
        return cls._instances[cls]



class Service( metaclass = Singleton ):
    """
    A singleton base class.
    """

